@@ -29,7 +29,7 @@ public:
         SelectionModel(parent)
     {
         append(tr("Continue"), Qdl::Continue);
-        append(tr("Stop"), Qdl::Stop);
+        append(tr("Pause"), Qdl::Pause);
         append(tr("Quit"), Qdl::Quit);
     }
 };
