@@ -78,7 +78,15 @@ int CaptchaDialog::timeout() const {
 void CaptchaDialog::setTimeout(int t) {
     m_timeout = t;
     m_remaining = t;
-    m_timer->start();
+    
+    if (t > 0) {
+        m_timeLabel->show();
+        m_timer->start();
+    }
+    else {
+        m_timeLabel->hide();
+        m_timer->stop();
+    }
 }
 
 int CaptchaDialog::timeRemaining() const {
@@ -90,7 +98,10 @@ void CaptchaDialog::showEvent(QShowEvent *event) {
 
     if (!m_timer->isActive()) {
         m_remaining = timeout();
-        m_timer->start();
+        
+        if (m_remaining > 0) {
+            m_timer->start();
+        }
     }
 }
 
