@@ -28,6 +28,9 @@
 #include "qdl.h"
 #include "recaptchapluginmanager.h"
 #include "retrieveurlsdialog.h"
+#include "searchdialog.h"
+#include "searchpage.h"
+#include "searchpluginmanager.h"
 #include "servicepluginmanager.h"
 #include "settings.h"
 #include "settingsdialog.h"
@@ -46,16 +49,20 @@
 #include <QMenu>
 #include <QMenuBar>
 #include <QMessageBox>
-#include <QTreeView>
+#include <QStackedWidget>
+#include <QTabBar>
 #include <QToolBar>
 #include <QToolButton>
+#include <QTreeView>
+#include <QVBoxLayout>
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     m_fileMenu(new QMenu(tr("&File"), this)),
     m_transferMenu(new QMenu(tr("&Download"), this)),
     m_packageMenu(new QMenu(tr("&Package"), this)),
-    m_editMenu(new QMenu(tr("&Edit"), this)),
+    m_viewMenu(new QMenu(tr("&View"), this)),
+    m_toolsMenu(new QMenu(tr("&Tools"), this)),
     m_helpMenu(new QMenu(tr("&Help"), this)),
     m_transferPriorityMenu(new QMenu(tr("&Priority"), this)),
     m_packageCategoryMenu(new QMenu(tr("&Category"), this)),
@@ -66,11 +73,11 @@ MainWindow::MainWindow(QWidget *parent) :
     m_bottomToolBar(new QToolBar(this)),
     m_addUrlsAction(new QAction(QIcon::fromTheme("list-add"), tr("&Add URLs"), this)),
     m_importUrlsAction(new QAction(QIcon::fromTheme("document-open"), tr("&Import URLs"), this)),
-    m_retrieveUrlsAction(new QAction(QIcon::fromTheme("edit-find"), tr("&Retrieve URLs"), this)),
+    m_retrieveUrlsAction(new QAction(QIcon::fromTheme("folder-remote"), tr("&Retrieve URLs"), this)),
     m_clipboardUrlsAction(new QAction(QIcon::fromTheme("edit-paste"), tr("Show &clipboard URLs"), this)),
+    m_searchAction(new QAction(QIcon::fromTheme("edit-find"), tr("&Search for content"), this)),
     m_queueAction(new QAction(QIcon::fromTheme("media-playback-start"), tr("&Start all downloads"), this)),
     m_pauseAction(new QAction(QIcon::fromTheme("media-playback-pause"), tr("&Pause all downloads"), this)),
-    m_pluginsAction(new QAction(QIcon::fromTheme("view-refresh"), tr("&Load plugins"), this)),
     m_quitAction(new QAction(QIcon::fromTheme("application-exit"), tr("&Quit"), this)),
     m_transferPropertiesAction(new QAction(QIcon::fromTheme("document-properties"), tr("&Properties"), this)),
     m_transferCustomCommandAction(new QAction(QIcon::fromTheme("system-run"), tr("Set &custom command"), this)),
@@ -84,20 +91,28 @@ MainWindow::MainWindow(QWidget *parent) :
     m_packagePauseAction(new QAction(QIcon::fromTheme("media-playback-pause"), tr("&Pause"), this)),
     m_packageCancelAction(new QAction(QIcon::fromTheme("edit-delete"), tr("&Remove"), this)),
     m_packageCancelDeleteAction(new QAction(QIcon::fromTheme("edit-delete"), tr("Remove and &delete files"), this)),
+    m_closePageAction(new QAction(QIcon::fromTheme("view-close"), tr("&Close tab"), this)),
+    m_transfersAction(new QAction(tr("Downloads"), this)),
+    m_pluginsAction(new QAction(QIcon::fromTheme("view-refresh"), tr("&Load plugins"), this)),
     m_settingsAction(new QAction(QIcon::fromTheme("preferences-desktop"), tr("&Preferences"), this)),
     m_aboutAction(new QAction(QIcon::fromTheme("help-about"), tr("&About"), this)),
     m_transferPriorityGroup(new QActionGroup(this)),
     m_packageCategoryGroup(new QActionGroup(this)),
     m_packagePriorityGroup(new QActionGroup(this)),
+    m_pageGroup(new QActionGroup(this)),
     m_concurrentTransfersGroup(new QActionGroup(this)),
     m_actionSelector(new QComboBox(this)),
-    m_view(new QTreeView(this)),
-    m_optionsButton(new QToolButton(this)),
     m_activeLabel(new QLabel(QString("%1DLs").arg(TransferModel::instance()->activeTransfers()), this)),
-    m_speedLabel(new QLabel(Utils::formatBytes(TransferModel::instance()->totalSpeed()) + "/s", this))
+    m_speedLabel(new QLabel(Utils::formatBytes(TransferModel::instance()->totalSpeed()) + "/s", this)),
+    m_optionsButton(new QToolButton(this)),
+    m_widget(new QWidget(this)),
+    m_tabs(new QTabBar(m_widget)),
+    m_stack(new QStackedWidget(m_widget)),
+    m_view(new QTreeView(m_stack)),
+    m_layout(new QVBoxLayout(m_widget))
 {
     setWindowTitle("QDL");
-    setCentralWidget(m_view);
+    setCentralWidget(m_widget);
     setAcceptDrops(true);
     addToolBar(Qt::TopToolBarArea, m_topToolBar);
     addToolBar(Qt::BottomToolBarArea, m_bottomToolBar);
@@ -111,14 +126,16 @@ MainWindow::MainWindow(QWidget *parent) :
     menuBar()->addMenu(m_fileMenu);
     menuBar()->addMenu(m_transferMenu);
     menuBar()->addMenu(m_packageMenu);
-    menuBar()->addMenu(m_editMenu);
+    menuBar()->addMenu(m_viewMenu);
+    menuBar()->addMenu(m_toolsMenu);
     menuBar()->addMenu(m_helpMenu);
 
     m_addUrlsAction->setShortcut(tr("Ctrl+N"));
     m_importUrlsAction->setShortcut(tr("Ctrl+O"));
     m_retrieveUrlsAction->setShortcut(tr("Ctrl+F"));
     m_clipboardUrlsAction->setShortcut(tr("Ctrl+U"));
-    m_pluginsAction->setShortcut(tr("Ctrl+L"));
+    m_searchAction->setShortcut(tr("Ctrl+S"));
+    m_searchAction->setEnabled(SearchPluginManager::instance()->count() > 0);
     m_quitAction->setShortcut(tr("Ctrl+Q"));
 
     m_fileMenu->addAction(m_addUrlsAction);
@@ -126,11 +143,11 @@ MainWindow::MainWindow(QWidget *parent) :
     m_fileMenu->addAction(m_retrieveUrlsAction);
     m_fileMenu->addAction(m_clipboardUrlsAction);
     m_fileMenu->addSeparator();
+    m_fileMenu->addAction(m_searchAction);
+    m_fileMenu->addSeparator();
     m_fileMenu->addAction(m_queueAction);
     m_fileMenu->addAction(m_pauseAction);
     m_fileMenu->addSeparator();
-    m_fileMenu->addAction(m_pluginsAction);
-    m_fileMenu->addSeparator();
     m_fileMenu->addAction(m_quitAction);
 
     m_transferMenu->addAction(m_transferPropertiesAction);
@@ -158,23 +175,34 @@ MainWindow::MainWindow(QWidget *parent) :
 
     for (int i = TransferItem::HighestPriority; i <= TransferItem::LowestPriority; i++) {
         QAction *transferAction =
-        m_transferPriorityMenu->addAction(TransferItem::priorityString(TransferItem::Priority(i)),
-                                          this, SLOT(setCurrentTransferPriority()));
+            m_transferPriorityMenu->addAction(TransferItem::priorityString(TransferItem::Priority(i)));
         transferAction->setData(i);
         transferAction->setCheckable(true);
         m_transferPriorityGroup->addAction(transferAction);
 
         QAction *packageAction =
-        m_packagePriorityMenu->addAction(TransferItem::priorityString(TransferItem::Priority(i)),
-                                         this, SLOT(setCurrentPackagePriority()));
+            m_packagePriorityMenu->addAction(TransferItem::priorityString(TransferItem::Priority(i)));
         packageAction->setData(i);
         packageAction->setCheckable(true);
         m_packagePriorityGroup->addAction(packageAction);
     }
+    
+    m_closePageAction->setShortcut(tr("Ctrl+W"));
+    m_closePageAction->setEnabled(false);
+    m_transfersAction->setCheckable(true);
+    m_transfersAction->setChecked(true);
+    
+    m_pageGroup->addAction(m_transfersAction);
+    m_pageGroup->setVisible(false);
+        
+    m_viewMenu->addAction(m_closePageAction);
+    m_viewMenu->addAction(m_transfersAction);
 
+    m_pluginsAction->setShortcut(tr("Ctrl+L"));
     m_settingsAction->setShortcut(tr("Ctrl+P"));
 
-    m_editMenu->addAction(m_settingsAction);
+    m_toolsMenu->addAction(m_pluginsAction);
+    m_toolsMenu->addAction(m_settingsAction);
 
     m_helpMenu->addAction(m_aboutAction);
 
@@ -182,6 +210,9 @@ MainWindow::MainWindow(QWidget *parent) :
 
     m_actionSelector->setModel(new ActionModel(m_actionSelector));
     m_actionSelector->setCurrentIndex(Settings::nextAction());
+    
+    QLabel *actionLabel = new QLabel(tr("&After current download(s): "), this);
+    actionLabel->setBuddy(m_actionSelector);
 
     m_topToolBar->setObjectName("topToolBar");
     m_topToolBar->setWindowTitle(tr("Top toolbar"));
@@ -192,10 +223,12 @@ MainWindow::MainWindow(QWidget *parent) :
     m_topToolBar->addAction(m_retrieveUrlsAction);
     m_topToolBar->addAction(m_clipboardUrlsAction);
     m_topToolBar->addSeparator();
+    m_topToolBar->addAction(m_searchAction);
+    m_topToolBar->addSeparator();
     m_topToolBar->addAction(m_queueAction);
     m_topToolBar->addAction(m_pauseAction);
     m_topToolBar->addSeparator();
-    m_topToolBar->addWidget(new QLabel(tr("After current download(s): "), m_topToolBar));
+    m_topToolBar->addWidget(actionLabel);
     m_topToolBar->addWidget(m_actionSelector);
 
     QLabel *speedIcon = new QLabel(m_bottomToolBar);
@@ -210,7 +243,7 @@ MainWindow::MainWindow(QWidget *parent) :
     const int concurrent = Settings::maximumConcurrentTransfers();
 
     for (int i = 1; i <= MAX_CONCURRENT_TRANSFERS; i++) {
-        QAction *action = m_concurrentTransfersMenu->addAction(QString::number(i), this, SLOT(setMaximumConcurrentTransfers()));
+        QAction *action = m_concurrentTransfersMenu->addAction(QString::number(i));
         action->setData(i);
         action->setCheckable(true);
         action->setChecked(i == concurrent);
@@ -233,6 +266,16 @@ MainWindow::MainWindow(QWidget *parent) :
     m_bottomToolBar->addWidget(spacer2);
     m_bottomToolBar->addWidget(m_speedLabel);
     m_bottomToolBar->addWidget(speedIcon);
+    
+    m_tabs->setTabsClosable(true);
+    m_tabs->setSelectionBehaviorOnRemove(QTabBar::SelectLeftTab);
+    m_tabs->setExpanding(false);
+    m_tabs->addTab(tr("Downloads"));
+    m_tabs->hide();
+    
+    if (QWidget *button = m_tabs->tabButton(0, QTabBar::RightSide)) {
+        button->hide();
+    }
 
     m_view->setModel(TransferModel::instance());
     m_view->setItemDelegate(new TransferDelegate(m_view));
@@ -259,6 +302,12 @@ MainWindow::MainWindow(QWidget *parent) :
         header->resizeSection(2, fm.width("999.99MB of 999.99MB (99.99%)") + 20);
         header->resizeSection(3, fm.width("999.99KB/s") + 20);
     }
+    
+    m_stack->addWidget(m_view);
+    
+    m_layout->addWidget(m_tabs);
+    m_layout->addWidget(m_stack);
+    m_layout->setContentsMargins(0, 0, 0, 0);
 
     connect(Categories::instance(), SIGNAL(changed()), this, SLOT(setCategoryMenuActions()));
 
@@ -276,9 +325,9 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(m_importUrlsAction, SIGNAL(triggered()), this, SLOT(showImportUrlsDialog()));
     connect(m_retrieveUrlsAction, SIGNAL(triggered()), this, SLOT(showRetrieveUrlsDialog()));
     connect(m_clipboardUrlsAction, SIGNAL(triggered()), this, SLOT(showClipboardUrlsDialog()));
+    connect(m_searchAction, SIGNAL(triggered()), this, SLOT(showSearchDialog()));
     connect(m_queueAction, SIGNAL(triggered()), TransferModel::instance(), SLOT(queue()));
     connect(m_pauseAction, SIGNAL(triggered()), TransferModel::instance(), SLOT(pause()));
-    connect(m_pluginsAction, SIGNAL(triggered()), this, SLOT(loadPlugins()));
     connect(m_quitAction, SIGNAL(triggered()), this, SLOT(quit()));
 
     connect(m_transferPropertiesAction, SIGNAL(triggered()), this, SLOT(showCurrentTransferProperties()));
@@ -294,11 +343,23 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(m_packagePauseAction, SIGNAL(triggered()), this, SLOT(pauseCurrentPackage()));
     connect(m_packageCancelAction, SIGNAL(triggered()), this, SLOT(cancelCurrentPackage()));
     connect(m_packageCancelDeleteAction, SIGNAL(triggered()), this, SLOT(cancelAndDeleteCurrentPackage()));
-
+    
+    connect(m_closePageAction, SIGNAL(triggered()), this, SLOT(closeCurrentPage()));
+    
+    connect(m_pluginsAction, SIGNAL(triggered()), this, SLOT(loadPlugins()));
     connect(m_settingsAction, SIGNAL(triggered()), this, SLOT(showSettingsDialog()));
+    
     connect(m_aboutAction, SIGNAL(triggered()), this, SLOT(showAboutDialog()));
+    
+    connect(m_transferPriorityGroup, SIGNAL(triggered(QAction*)), this, SLOT(setCurrentTransferPriority(QAction*)));
+    connect(m_packageCategoryGroup, SIGNAL(triggered(QAction*)), this, SLOT(setCurrentPackageCategory(QAction*)));
+    connect(m_packagePriorityGroup, SIGNAL(triggered(QAction*)), this, SLOT(setCurrentPackagePriority(QAction*)));
+    connect(m_pageGroup, SIGNAL(triggered(QAction*)), this, SLOT(setCurrentPage(QAction*)));
 
     connect(m_actionSelector, SIGNAL(activated(int)), Settings::instance(), SLOT(setNextAction(int)));
+        
+    connect(m_tabs, SIGNAL(currentChanged(int)), this, SLOT(setCurrentPage(int)));
+    connect(m_tabs, SIGNAL(tabCloseRequested(int)), this, SLOT(closePage(int)));
 
     connect(m_view, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
     connect(m_view->selectionModel(), SIGNAL(currentRowChanged(QModelIndex, QModelIndex)),
@@ -369,11 +430,9 @@ void MainWindow::setCurrentTransferCustomCommand() {
     }
 }
 
-void MainWindow::setCurrentTransferPriority() {
-    if (const QAction *action = m_transferPriorityGroup->checkedAction()) {
-        if (m_view->currentIndex().data(TransferItem::ItemTypeRole) == TransferItem::TransferType) {
-            TransferModel::instance()->setData(m_view->currentIndex(), action->data(), TransferItem::PriorityRole);
-        }
+void MainWindow::setCurrentTransferPriority(QAction *action) {
+    if (m_view->currentIndex().data(TransferItem::ItemTypeRole) == TransferItem::TransferType) {
+        TransferModel::instance()->setData(m_view->currentIndex(), action->data(), TransferItem::PriorityRole);
     }
 }
 
@@ -415,11 +474,9 @@ void MainWindow::cancelAndDeleteCurrentPackage() {
     }
 }
 
-void MainWindow::setCurrentPackageCategory() {
-    if (const QAction *action = m_packageCategoryGroup->checkedAction()) {
-        if (m_view->currentIndex().data(TransferItem::ItemTypeRole) == TransferItem::PackageType) {
-            TransferModel::instance()->setData(m_view->currentIndex(), action->data(), TransferItem::CategoryRole);
-        }
+void MainWindow::setCurrentPackageCategory(QAction *action) {
+    if (m_view->currentIndex().data(TransferItem::ItemTypeRole) == TransferItem::PackageType) {
+        TransferModel::instance()->setData(m_view->currentIndex(), action->data(), TransferItem::CategoryRole);
     }
 }
 
@@ -429,11 +486,9 @@ void MainWindow::setCurrentPackageSubfolder(bool enabled) {
     }
 }
 
-void MainWindow::setCurrentPackagePriority() {
-    if (const QAction *action = m_packagePriorityGroup->checkedAction()) {
-        if (m_view->currentIndex().data(TransferItem::ItemTypeRole) == TransferItem::PackageType) {
-            TransferModel::instance()->setData(m_view->currentIndex(), action->data(), TransferItem::PriorityRole);
-        }
+void MainWindow::setCurrentPackagePriority(QAction *action) {
+    if (m_view->currentIndex().data(TransferItem::ItemTypeRole) == TransferItem::PackageType) {
+        TransferModel::instance()->setData(m_view->currentIndex(), action->data(), TransferItem::PriorityRole);
     }
 }
 
@@ -453,7 +508,7 @@ void MainWindow::setMaximumConcurrentTransfers() {
 
 void MainWindow::setCategoryMenuActions() {
     m_packageCategoryMenu->clear();
-    QAction *categoryAction = m_packageCategoryMenu->addAction(tr("Default"), this, SLOT(setCurrentPackageCategory()));
+    QAction *categoryAction = m_packageCategoryMenu->addAction(tr("Default"));
     categoryAction->setData(QString());
     categoryAction->setCheckable(true);
     m_packageCategoryGroup->addAction(categoryAction);
@@ -461,7 +516,7 @@ void MainWindow::setCategoryMenuActions() {
     const CategoryList categories = Categories::get();
 
     for (int i = 0; i < categories.size(); i++) {
-        categoryAction = m_packageCategoryMenu->addAction(categories.at(i).name, this, SLOT(setCurrentPackageCategory()));
+        categoryAction = m_packageCategoryMenu->addAction(categories.at(i).name);
         categoryAction->setData(categoryAction->text());
         categoryAction->setCheckable(true);
         m_packageCategoryGroup->addAction(categoryAction);
@@ -520,6 +575,62 @@ void MainWindow::showOptionsMenu() {
     m_optionsMenu->popup(m_optionsButton->mapToGlobal(m_optionsButton->rect().center()));
 }
 
+void MainWindow::closePage(int index) {
+    if (index > 0) {
+        if (QWidget *page = m_stack->widget(index)) {
+            m_stack->removeWidget(page);
+            m_tabs->removeTab(index);
+            page->close();
+            
+            if (m_tabs->count() == 1) {
+                m_tabs->hide();
+                m_pageGroup->setVisible(false);
+            }
+            
+            if ((index >= 0) && (index < m_pageGroup->actions().size())) {
+                QAction *action = m_pageGroup->actions().at(index);
+                m_pageGroup->removeAction(action);
+                m_viewMenu->removeAction(action);
+                action->deleteLater();
+            }
+        }
+    }
+}
+
+void MainWindow::closeCurrentPage() {
+    closePage(m_tabs->currentIndex());
+}
+
+void MainWindow::setCurrentPage(int index) {
+    m_stack->setCurrentIndex(index);
+    m_closePageAction->setEnabled(index > 0);
+    
+    if ((index >= 0) && (index < m_pageGroup->actions().size())) {
+        m_pageGroup->actions().at(index)->setChecked(true);
+    }
+}
+
+void MainWindow::setCurrentPage(QAction *action) {
+    m_tabs->setCurrentIndex(m_pageGroup->actions().indexOf(action));
+}
+
+void MainWindow::search(const QString &pluginName, const QString &pluginId) {
+    const QString text = tr("Search - %1").arg(pluginName);
+    SearchPage *page = new SearchPage(m_stack);
+    m_stack->addWidget(page);
+    const int index = m_stack->indexOf(page);
+    m_tabs->addTab(text);
+    m_stack->setCurrentIndex(index);
+    m_tabs->setCurrentIndex(index);
+    m_tabs->show();
+    QAction *action = m_viewMenu->addAction(text);
+    action->setCheckable(true);
+    action->setChecked(true);
+    m_pageGroup->addAction(action);
+    m_pageGroup->setVisible(true);
+    page->search(pluginId);
+}
+
 void MainWindow::showAddUrlsDialog() {
     AddUrlsDialog addDialog(this);
 
@@ -548,9 +659,15 @@ void MainWindow::showAddUrlsDialog(const QStringList &urls) {
         const QStringList urls = addDialog.urls();
 
         if (!urls.isEmpty()) {
-            UrlCheckDialog checkDialog(this);
-            checkDialog.addUrls(urls);
-            checkDialog.exec();
+            if (addDialog.usePlugins()) {
+                UrlCheckDialog checkDialog(this);
+                checkDialog.addUrls(urls);
+                checkDialog.exec();
+            }
+            else {
+                TransferModel::instance()->append(urls, addDialog.requestMethod(), addDialog.requestHeaders(),
+                                                  addDialog.postData());
+            }
         }
     }
 }
@@ -608,19 +725,14 @@ void MainWindow::showRetrieveUrlsDialog(const QStringList &urls) {
 }
 
 void MainWindow::showClipboardUrlsDialog() {
-    ClipboardUrlsDialog dialog(this);
+    ClipboardUrlsDialog(this).exec();
+}
 
+void MainWindow::showSearchDialog() {
+    SearchDialog dialog(this);
+    
     if (dialog.exec() == QDialog::Accepted) {
-        const QStringList urls = dialog.urls();
-
-        if (!urls.isEmpty()) {
-            if (dialog.action() == Qdl::RetrieveUrls) {
-                showRetrieveUrlsDialog(urls);
-            }
-            else {
-                showAddUrlsDialog(urls);
-            }
-        }
+        search(dialog.pluginName(), dialog.pluginId());
     }
 }
 
@@ -683,11 +795,18 @@ void MainWindow::showPluginSettingsDialog(TransferItem *t) {
 }
 
 void MainWindow::loadPlugins() {
-    const int count = DecaptchaPluginManager::instance()->load() + RecaptchaPluginManager::instance()->load()
-                      + ServicePluginManager::instance()->load();
+    const int decaptcha = DecaptchaPluginManager::instance()->load();
+    const int recaptcha = RecaptchaPluginManager::instance()->load();
+    const int search = SearchPluginManager::instance()->load();
+    const int services = ServicePluginManager::instance()->load();
+    const int count = decaptcha + recaptcha + search + services;
 
     if (count > 0) {
         QMessageBox::information(this, tr("Load plugins"), tr("%1 new plugins found").arg(count));
+        
+        if (search > 0) {
+            m_searchAction->setEnabled(true);
+        }
     }
     else {
         QMessageBox::information(this, tr("Load plugins"), tr("No new plugins found"));
