@@ -30,6 +30,8 @@ class Settings : public QObject
                NOTIFY customCommandEnabledChanged)
     Q_PROPERTY(QString decaptchaPlugin READ decaptchaPlugin WRITE setDecaptchaPlugin NOTIFY decaptchaPluginChanged)
     Q_PROPERTY(QString defaultCategory READ defaultCategory WRITE setDefaultCategory NOTIFY defaultCategoryChanged)
+    Q_PROPERTY(QString defaultSearchPlugin READ defaultSearchPlugin WRITE setDefaultSearchPlugin
+               NOTIFY defaultSearchPluginChanged)
     Q_PROPERTY(QString defaultServicePlugin READ defaultServicePlugin WRITE setDefaultServicePlugin
                NOTIFY defaultServicePluginChanged)
     Q_PROPERTY(bool usePlugins READ usePlugins WRITE setUsePlugins NOTIFY usePluginsChanged)
@@ -67,6 +69,7 @@ class Settings : public QObject
                NOTIFY webInterfaceUsernameChanged)
     Q_PROPERTY(QString webInterfacePassword READ webInterfacePassword WRITE setWebInterfacePassword
                NOTIFY webInterfacePasswordChanged)
+    Q_PROPERTY(QByteArray searchPageState READ searchPageState WRITE setSearchPageState)
     Q_PROPERTY(QByteArray transferViewHeaderState READ transferViewHeaderState WRITE setTransferViewHeaderState)
     Q_PROPERTY(QByteArray windowGeometry READ windowGeometry WRITE setWindowGeometry)
     Q_PROPERTY(QByteArray windowState READ windowState WRITE setWindowState)
@@ -84,7 +87,9 @@ public:
     static QString decaptchaPlugin();
 
     static QString defaultCategory();
-
+    
+    static QString defaultSearchPlugin();
+    
     static QString defaultServicePlugin();
     static bool usePlugins();
 
@@ -117,6 +122,7 @@ public:
     static QString webInterfaceUsername();
     static QString webInterfacePassword();
     
+    static QByteArray searchPageState();
     static QByteArray transferViewHeaderState();
     static QByteArray windowGeometry();
     static QByteArray windowState();
@@ -130,7 +136,9 @@ public Q_SLOTS:
     static void setDecaptchaPlugin(const QString &pluginId);
     
     static void setDefaultCategory(const QString &category);
-
+    
+    static void setDefaultSearchPlugin(const QString &pluginId);
+    
     static void setDefaultServicePlugin(const QString &pluginId);
     static void setUsePlugins(bool enabled);
 
@@ -165,6 +173,7 @@ public Q_SLOTS:
     static void setWebInterfaceUsername(const QString &username);
     static void setWebInterfacePassword(const QString &password);
     
+    static void setSearchPageState(const QByteArray &state);
     static void setTransferViewHeaderState(const QByteArray &state);
     static void setWindowGeometry(const QByteArray &geometry);
     static void setWindowState(const QByteArray &state);
@@ -175,6 +184,7 @@ Q_SIGNALS:
     void customCommandEnabledChanged(bool enabled);
     void decaptchaPluginChanged(const QString &pluginId);
     void defaultCategoryChanged(const QString &category);
+    void defaultSearchPluginChanged(const QString &pluginId);
     void defaultServicePluginChanged(const QString &pluginId);
     void usePluginsChanged(bool enabled);
     void downloadPathChanged(const QString &path);
