@@ -38,6 +38,9 @@ static const QStringList DECAPTCHA_PLUGIN_PATHS = QStringList() << QString("/opt
 static const QStringList RECAPTCHA_PLUGIN_PATHS = QStringList() << QString("/opt/qdl2/plugins/recaptcha/")
                                                                 << QString(HOME_PATH + "/qdl2/plugins/recaptcha/");
 
+static const QStringList SEARCH_PLUGIN_PATHS = QStringList() << QString("/opt/qdl2/plugins/search/")
+                                                             << QString(HOME_PATH + "/qdl2/plugins/search/");
+
 static const QStringList SERVICE_PLUGIN_PATHS = QStringList() << QString("/opt/qdl2/plugins/services/")
                                                               << QString(HOME_PATH + "/qdl2/plugins/services/");
 
@@ -63,6 +66,6 @@ static const int MAX_CONCURRENT_TRANSFERS = 4;
 static const int MAX_REDIRECTS = 8;
 
 // Version
-static const QString VERSION_NUMBER("2.3.0");
+static const QString VERSION_NUMBER("2.4.0");
 
 #endif // DEFINITIONS_H
