@@ -89,6 +89,10 @@ void PluginDialog::addLineEdit(const QString &label, const QString &key, const Q
     if (isPassword) {
         edit->setEchoMode(QLineEdit::Password);
     }
+    
+    if (!focusWidget()) {
+        edit->setFocus();
+    }
 
     m_vbox->addWidget(new QLabel(label, m_container));
     m_vbox->addWidget(edit);
