@@ -602,6 +602,10 @@ QVariantMap Qdl::getUrlChecks() {
     QVariantMap map;
     map["count"] = UrlCheckModel::instance()->rowCount();
     map["progress"] = UrlCheckModel::instance()->progress();
+    map["requestedSettings"] = UrlCheckModel::instance()->requestedSettings();
+    map["requestedSettingsTimeout"] = UrlCheckModel::instance()->requestedSettingsTimeout();
+    map["requestedSettingsTimeoutString"] = UrlCheckModel::instance()->requestedSettingsTimeoutString();
+    map["requestedSettingsTitle"] = UrlCheckModel::instance()->requestedSettingsTitle();
     map["status"] = UrlCheckModel::instance()->status();
     map["statusString"] = UrlCheckModel::instance()->statusString();
     
@@ -635,6 +639,10 @@ bool Qdl::removeUrlCheck(const QString &url) {
     return UrlCheckModel::instance()->removeRow(index.row());
 }
 
+bool Qdl::submitUrlCheckSettingsResponse(const QVariantMap &settings) {
+    return UrlCheckModel::instance()->submitSettingsResponse(settings);
+}
+
 QVariantMap Qdl::getUrlRetrievals() {
     QVariantMap map;
     map["count"] = UrlRetrievalModel::instance()->rowCount();
