@@ -57,11 +57,7 @@ QVariant DecaptchaPluginConfigModel::data(const QModelIndex &index, int role) co
     
     switch (role) {
     case Qt::DecorationRole:
-        if (!config->iconFilePath().isEmpty()) {
-            return QIcon(config->iconFilePath());
-        }
-
-        return QVariant();
+        return QIcon(config->iconFilePath());
     case DisplayNameRole:
         return config->displayName();
     case FilePathRole:
