@@ -45,6 +45,10 @@ ServicePluginManager* ServicePluginManager::instance() {
     return self ? self : self = new ServicePluginManager;
 }
 
+int ServicePluginManager::count() const {
+    return m_plugins.size();
+}
+
 ServicePluginList ServicePluginManager::plugins() const {
     return m_plugins;
 }
@@ -205,6 +209,7 @@ int ServicePluginManager::load() {
 
     if (count > 0) {
         qSort(m_plugins.begin(), m_plugins.end(), displayNameLessThan);
+        emit countChanged(m_plugins.size());
     }
 
     m_lastLoaded = QDateTime::currentDateTime();
