@@ -39,11 +39,15 @@ typedef QList<ServicePluginPair> ServicePluginList;
 class ServicePluginManager : public QObject
 {
     Q_OBJECT
+    
+    Q_PROPERTY(int count READ count NOTIFY countChanged)
 
 public:
     ~ServicePluginManager();
 
     static ServicePluginManager* instance();
+    
+    int count() const;
 
     ServicePluginList plugins() const;
 
@@ -61,6 +65,9 @@ public Q_SLOTS:
 
     int load();
 
+Q_SIGNALS:
+    void countChanged(int count);
+
 private:
     ServicePluginManager();
 
