@@ -482,7 +482,7 @@ bool Package::moveFiles() {
             const QString newFilePath = Utils::getSaveFileName(oldFileName, outputPath);
             
             if ((newFilePath.isEmpty()) || (!file.rename(oldFilePath, newFilePath))) {
-                Logger::log(QString("Package::moveFiles(): Cannot rename %1 to %2").arg(oldFilePath).arg(newFilePath)
+                Logger::log(QString("Package::moveFiles(): Cannot rename %1 to %2").arg(oldFilePath).arg(newFilePath),
                             Logger::LowVerbosity);
                 setErrorString(tr("Cannot move files: %1").arg(file.errorString()));
                 return false;
